Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'indexer/mwm_set.hpp')
-rw-r--r--indexer/mwm_set.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indexer/mwm_set.hpp b/indexer/mwm_set.hpp
index 9e193f31e7..62d708734f 100644
--- a/indexer/mwm_set.hpp
+++ b/indexer/mwm_set.hpp
@@ -29,7 +29,7 @@
class MwmInfo
{
public:
- friend class DataSourceBase;
+ friend class DataSource;
friend class MwmSet;
enum MwmTypeT
@@ -91,7 +91,7 @@ protected:
class MwmInfoEx : public MwmInfo
{
private:
- friend class DataSourceBase;
+ friend class DataSource;
friend class MwmValue;
// weak_ptr is needed here to access offsets table in already
@@ -315,7 +315,7 @@ public:
MwmHandle GetMwmHandleById(MwmId const & id);
/// Now this function looks like workaround, but it allows to avoid ugly const_cast everywhere..
/// Client code usually holds const reference to DataSourceBase, but implementation is non-const.
/// @todo Actually, we need to define, is this behaviour (getting Handle) const or non-const.
MwmHandle GetMwmHandleById(MwmId const & id) const
{
@@ -315,7 +315,7 @@ public:
MwmHandle GetMwmHandleById(MwmId const & id);
/// Now this function looks like workaround, but it allows to avoid ugly const_cast everywhere..
- /// Client code usually holds const reference to DataSourceBase, but implementation is non-const.
+ /// Client code usually holds const reference to DataSource, but implementation is non-const.
/// @todo Actually, we need to define, is this behaviour (getting Handle) const or non-const.
MwmHandle GetMwmHandleById(MwmId const & id) const